/** @file

hippodraw::QtGroupView class implementation

Copyright (C) 2001-2006   The Board of Trustees of The Leland
Stanford Junior University.  All Rights Reserved.

$Id: QtGroupView.cxx,v 1.5 2006/05/05 18:24:33 pfkeb Exp $
 
*/

#ifdef _MSC_VER
#include "msdevstudio/MSconfig.h"
#endif

#include "QtGroupView.h"
#include "DrawBorder.h"

#include "qpainter.h"
//#if QT_VERSION < 0x040000
//#else
//#include <QPaintEngine>
//#endif

#include <cassert>
#include <iostream>


using std::vector;

using namespace hippodraw;

QtGroupView::QtGroupView ( )
  :GroupViewBase (),
   QtViewImp (),
#if QT_VERSION < 0x040000
    QCanvasRectangle ( 0 )
#else
    Q3CanvasRectangle ( 0 )
#endif
{
}

   
QtGroupView::QtGroupView ( const std::vector < ViewBase * > & inViews )
  :GroupViewBase ( inViews ),
   QtViewImp (),
#if QT_VERSION < 0x040000
    QCanvasRectangle ( 0 )
#else
    Q3CanvasRectangle ( 0 )
#endif
{
}

QtGroupView::~QtGroupView ()
{
  vector < ViewBase * >::const_iterator first = mViews.begin();
  for ( ; first != mViews.end(); ++first ) {
    //QtView * qtview = dynamic_cast < QtView * > ( *first );
    delete (*first);
  }  
}


void QtGroupView::setDrawRect ( float x, float y, float w, float h )
{
  // setX() and setY() will call moveBy()
  // set this flag to true so that the overridden moveBy() will not
  // move the views.
  m_is_drawing=true;    

  setX ( x );
  setY ( y );

  int iw = static_cast< int > ( w );
  int ih = static_cast< int > ( h );
  setSize ( iw, ih );

  m_is_drawing=false;

  if ( m_position.size() == 0 ) return;   // first time to set draw rect.

  // set draw rectangle for every views.
  vector < ViewBase * >::const_iterator first = mViews.begin();
  for ( unsigned int i = 0; first != mViews.end(); ++first, i=i+4 ) {
    QtView * qtview = dynamic_cast < QtView * > ( *first );

    qtview->setDrawRect ( x+w*m_position[i],
			  y+h*m_position[i+1],
			  w*m_position[i+2],
			  h*m_position[i+3] );
  } 
}

void QtGroupView::setDrawRect ( const QRect & rect )
{
  setDrawRect ( rect.x (), rect.y (), rect.width (), rect. height () );
}

Rect QtGroupView::getDrawRect () const
{
  return Rect ( x(), y(), width(), height() );
}


void QtGroupView::draw ( QPainter & painter )

{
  // only draw the border

  m_is_drawing = true;
  
  const QColor color ( "black" );
  painter.setPen ( color );
  m_painter = & painter;

  if ( isSelected () )
    {
      DrawBorder * border = DrawBorder::instance();
      border->setView (this);
      border->draw();
    }
  m_is_drawing = false;
}



// Abstract methods from QtViewImp class.
void
QtGroupView::
fillPickedPoint ( double dx, double dy,
		  std::vector < double > & picked ) const
{
}

int QtGroupView::toCanvasX ( double dx ) const
{
  return static_cast < int > ( x() + dx );
}

int QtGroupView::toCanvasY ( double dy ) const
{
  return static_cast < int > ( y() + dy );
}


int QtGroupView::toViewX ( double datX ) const
{
  return 0;
  //return static_cast< int > ( x() + userToMarginX ( datX ) );
}

int QtGroupView::toViewY ( double datY ) const
{
  return 0;
  //return static_cast< int > ( y() + userToInvertedMarginY ( datY ) );
}

void QtGroupView::moveBy ( double dx, double dy )
{
#if QT_VERSION < 0x040000
  QCanvasRectangle::moveBy ( dx, dy );
#else
  Q3CanvasRectangle::moveBy (dx, dy);
#endif
  
  if ( m_is_drawing == true ) return;

  vector < ViewBase * >::const_iterator first = mViews.begin();
  for ( ; first != mViews.end(); ++first ) {
    QtView * qtview = dynamic_cast < QtView * > ( *first );
    qtview->moveBy ( dx, dy );
  }
}

void QtGroupView::setPositions()
{

  // Is it OK to convert int to double?
  vector < ViewBase * >::const_iterator first = mViews.begin();
  for ( ; first != mViews.end(); ++first ) {
    QtView * qtview = dynamic_cast < QtView * > ( *first );
    m_position.push_back( (qtview->x()-x())/width() );
    m_position.push_back( (qtview->y()-y())/height() );
    m_position.push_back( ((double)(qtview->width()))/width() );
    m_position.push_back( ((double)(qtview->height()))/height() );
  }
}

